@@ -7,8 +7,6 @@ import pytz
 import re
 import requests
 import requests_cache
-import tempfile
-from pathlib import Path
 
 """
 INFO:
@@ -25,7 +23,7 @@ VMM_BASE = "https://download.waterinfo.be/tsmdownload/KiWIS/KiWIS"
 VMM_AUTH = "http://download.waterinfo.be/kiwis-auth/token"
 HIC_BASE = "https://hicws.vlaanderen.be/KiWIS/KiWIS"
 HIC_AUTH = "https://hicwsauth.vlaanderen.be/auth"
-DATA_PATH = pkg_resources.resource_filename(__name__, "/data")
+DATA_PATH = pkg_resources.resource_filename(__name__, "./data")
 
 # Custom hard-coded fix for the decoding issue #1 of given returnfields
 DECODE_ERRORS = ["AV Quality Code Color", "RV Quality Code Color"]
@@ -75,9 +73,11 @@ class Waterinfo:
 
         # Use requests-cache session
         self._request = requests_cache.CachedSession(
-            cache_name=Path(tempfile.gettempdir()) / "pywaterinfo_cache.sqlite",
+            cache_name="pywaterinfo_cache.sqlite",
             backend="sqlite",
             expire_after=CACHE_RETENTION,
+            stale_if_error=False,
+            use_temp=True,
         )
 
         self.__default_args = {
@@ -126,9 +126,7 @@ class Waterinfo:
 
         # clean up cache old entries (requests-cache only removes/updates
         # entries that are reused, so this remove piling too much cache.)
-        self._request.cache.remove_expired_responses(
-            datetime.datetime.utcnow() - CACHE_RETENTION
-        )
+        self._request.remove_expired_responses(CACHE_RETENTION)
 
     def __repr__(self):
         return f"<{self.__class__.__name__} object, " f"Query from {self._base_url!r}>"
@@ -239,9 +237,13 @@ class Waterinfo:
         supported_parameters = set(
             self._kiwis_info[request]["QueryFields"]["Content"].keys()
         )
-        optional_parameters = set(
-            self._kiwis_info[request]["Optionalfields"]["Content"].keys()
-        )
+
+        if "Optionalfields" in self._kiwis_info[request]:
+            optional_parameters = set(
+                self._kiwis_info[request]["Optionalfields"]["Content"].keys()
+            )
+        else:
+            optional_parameters = set()
 
         for (parameter, _) in query.items():
             if parameter not in (
@@ -477,7 +479,7 @@ class Waterinfo:
             as a valid Timestamp.
         kwargs :
             Additional query parameter options as documented by KIWIS waterinfo API,
-            see `API docoumentation <https://download.waterinfo.be/tsmdownload/
+            see `API documentation <https://download.waterinfo.be/tsmdownload/
             KiWIS/KiWIS?service=kisters&type=QueryServices&format=html&
             request=getrequestinfo>`_
 
@@ -609,7 +611,7 @@ class Waterinfo:
             will select 0 or 1 timeseries per station in the area according to filters
         kwargs :
             Additional query parameter options as documented by KIWIS waterinfo API, see
-            `API docoumentation <https://download.waterinfo.be/tsmdownload/
+            `API documentation <https://download.waterinfo.be/tsmdownload/
             KiWIS/KiWIS?service=kisters&type=QueryServices&format=html&
             request=getrequestinfo>`_
 
@@ -696,7 +698,7 @@ class Waterinfo:
             Specify the type station, parameter or timeseries
         kwargs :
             Additional queryfields as accepted by the KIWIS call getGroupList, see
-            `API docoumentation <https://download.waterinfo.be/tsmdownload/
+            `API documentation <https://download.waterinfo.be/tsmdownload/
             KiWIS/KiWIS?service=kisters&type=QueryServices&format=html&
             request=getrequestinfo>`_
 
