@@ -10,6 +10,7 @@ from pandas.api import types
 from pandas.api.types import is_datetime64tz_dtype
 
 from pywaterinfo import HIC_BASE, VMM_BASE, Waterinfo
+from pywaterinfo.waterinfo import WaterinfoException
 
 
 def test_waterinfo_repr(vmm_connection, hic_connection):
@@ -56,10 +57,7 @@ def test_token_vmm():
 
     # token, token header, authentication in request header
     # this client code is received by VMM for unit testing purposes only
-    client = (
-        "MzJkY2VlY2UtODI2Yy00Yjk4LTljMmQtYjE2OTc4ZjBjYTZhOjRhZGE"
-        "4NzFhLTk1MjgtNGI0ZC1iZmQ1LWI1NzBjZThmNGQyZA=="
-    )
+    client = os.environ.get("VMM_TOKEN")
     vmm = Waterinfo("vmm", token=client)
     vmm.clear_cache()
     assert vmm._token_header is not None
@@ -345,11 +343,23 @@ class TestDatetimeHandling:
             "2019-05-01 12:05:00+00:00"
         )
 
+    def test_invalid_timezone(self, vmm_connection):
+        """Unknown timezone should raise error"""
+        with pytest.raises(pytz.exceptions.UnknownTimeZoneError):
+            vmm_connection.get_timeseries_values(
+                ts_id="60992042",
+                start="20190501 14:05:00+02:00",
+                end="20190501 14:10:00+02:00",
+                timezone="DUMMY",
+            )
+
     def test_return_date_format(self, vmm_connection):
         """Input to requested return date format should be existing on KIWIS API"""
         with pytest.raises(Exception):
             vmm_connection._check_return_date_format("DUMMY")
 
+        assert vmm_connection._check_return_date_format("yyyy-MM-dd HH:mm:ss") is None
+
     def test_return_fields_format(self, vmm_connection):
         """Input to requested returnfields should be existing on KIWIS API"""
         with pytest.raises(Exception):
@@ -389,14 +399,75 @@ class TestTimeseriesValues:
         )
         assert len(df) == 0
 
+    def test_datetime_conversion(self, vmm_connection):
+        """Datetime in the returned data sets are pd.Timestamps with timezone info"""
+        vmm_connection.clear_cache()
+        df = vmm_connection.get_timeseries_values(
+            ts_id="60992042,60968042", start="20190501 14:05", end="20190501 14:10"
+        )
+        assert pd.core.dtypes.common.is_datetime64tz_dtype(df["Timestamp"])
+
+
+class TestRequestKiwis:
+    def test_period_check_call(self, vmm_connection):
+        """period format checked when included"""
+        with pytest.raises(WaterinfoException):
+            vmm_connection.request_kiwis(
+                {
+                    "request": "getTimeseriesValues",
+                    "ts_id": "78124042",
+                    "period": "PTT1D",
+                }
+            )
+
+    def test_dateformat_check(self, vmm_connection):
+        """dateformat checked when included"""
+        with pytest.raises(WaterinfoException) as e:
+            vmm_connection.request_kiwis(
+                {
+                    "request": "getTimeseriesValues",
+                    "ts_id": "78124042",
+                    "period": "P1D",
+                    "dateformat": "",
+                }
+            )
+            assert str(e.value).contains("The requested returned datetime")
+
+    def test_queryparam_check(self, vmm_connection):
+        """dateformat checked when included"""
+        with pytest.raises(WaterinfoException):
+            vmm_connection.request_kiwis(
+                {"request": "getTimeseriesValues", "ts_id": "78124042", "DUMMY": ""}
+            )
+
+    def test_query_optional_fields(self, vmm_connection):
+        """Query check on optional fields works for requests without optional fields"""
+
+        # Kiwis calls without optional fields
+        no_optional_fields = [
+            "getColorClassifications",
+            "getQualityCodes",
+            "getTimeseriesReleaseStateList",
+        ]
+        for kiwis_request in no_optional_fields:
+            assert (
+                vmm_connection._check_query_parameters({"request": kiwis_request})
+                is None
+            )
+
 
 class TestTimeseriesValueLayer:
     def test_one_of_three(self, vmm_connection):
+        """Should be either ts_id, bbox or timeseriesgroup_id"""
         with pytest.raises(Exception):
             vmm_connection.get_timeseries_value_layer(
                 ts_id="78124042", timeseriesgroup_id="192900", bbox="DUMMY"
             )
 
+    def test_hic(self, hic_connection):
+        df = hic_connection.get_timeseries_value_layer(timeseriesgroup_id="156207")
+        assert "ts_id" in df.columns
+
 
 class TestGroupList:
     def test_group_type(self, vmm_connection):
@@ -408,6 +479,10 @@ class TestGroupList:
         with pytest.raises(Exception):
             vmm_connection.get_group_list(group_type="DUMMY")
 
+    def test_hic(self, hic_connection):
+        df = hic_connection.get_group_list()
+        assert "group_id" in df.columns
+
 
 class TestTimeseriesList:
     def test_no_data(self, vmm_connection):
@@ -415,3 +490,8 @@ class TestTimeseriesList:
         assert vmm_connection.get_timeseries_list(station_no="DUMMY").equals(
             pd.DataFrame([])
         )
+
+    def test_hic(self, hic_connection):
+        """"""
+        df = hic_connection.get_timeseries_list(station_no="plu03a-1066")
+        assert "station_no" in df.columns
